################### rover_environemnt.rb achase@mbari.org  #####################
#
# loading this class will setup the path to include the appropriate libraries
# for the rover
#
################################################################################
class RoverEnvironment
  def self.setPath
    sep = File::SEPARATOR
    $LOAD_PATH.unshift("..#{sep}esp#{sep}esp#{sep}lib#{sep}")
  end

  RoverEnvironment.setPath
end
